@@ -30,7 +30,7 @@ our @EXPORT_OK = (
 
 our @EXPORT = qw();
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 require XSLoader;
 XSLoader::load('Linux::Sys::CPU::Affinity', $VERSION);
@@ -46,10 +46,9 @@ Linux::Sys::CPU::Affinity - Perl XS extension for setupping CPU affinity
   use Linux::Sys::CPU::Affinity / :cpu :nprocs /;
 
   my @cpus = (0, 10, 70 .. 80);
-  my $ca = Linux::Sys::CPU::Affinity->new(\@cpus);
 
-  # the same as @cpus used above is empty
-  my $ca = Linux::Sys::CPU::Affinity->new();
+  my $ca = Linux::Sys::CPU::Affinity->new(); # the same as below, but @cpus is empty
+  my $ca = Linux::Sys::CPU::Affinity->new(\@cpus);
 
   $ca->cpu_zero();
   cpu_zero($ca);
@@ -78,11 +77,9 @@ Linux::Sys::CPU::Affinity - Perl XS extension for setupping CPU affinity
   my $new_ca = $first_ca->cpu_or($second_ca);
   my $new_ca = cpu_or($first_ca, $second_ca);
 
+  $ca->reset(); # the same as below, but @cpus is empty
   $ca->reset(\@new_cpus);
 
-  # the same as @new_cpus used above is empty
-  $ca->reset();
-
   my $is_success = $ca->set_affinity($pid);
   my $cpus_array = $ca->get_affinity($pid); # from the PID
 
@@ -90,7 +87,7 @@ Linux::Sys::CPU::Affinity - Perl XS extension for setupping CPU affinity
 
   my $new_ca = $ca->clone();
 
-  $ca->DESTROY(); # the same as C<undef $ca;>
+  $ca->DESTROY(); # the same as "undef $ca;"
 
   my $nprocs = get_nprocs();
 
@@ -173,17 +170,17 @@ Returns nonzero if the two CPU sets are equal; otherwise returns 0.
 
 Returns the array reference with CPUS's numbers which are presented in set.
 Please, keep in mind, that this set can be not applied yet to any PID.
-To apply this set you can use <set_affinity> method.
+To apply this set you can use C<set_affinity> method.
 
-=head cpu_and
+=head2 cpu_and
 
 Stores he intersection of the sets C<$ca1> and C<$ca2> in the new set, and returns it.
 
-=head cpu_or
+=head2 cpu_or
 
 Stores the union of the sets C<$ca1> and C<$ca2> in the new set, and returns it.
 
-=head cpu_xor
+=head2 cpu_xor
 
 Stores the XOR of the sets C<$ca1> and C<$ca2> in the new set, and returns it.
 The XOR means the set of CPUs that are in either C<$ca1> or C<$ca2>, but not both.
@@ -204,6 +201,6 @@ Returns the amount of available CPU cores (see detail in get_nprocs(3) Linux Man
 
 =head1 AUTHOR
 
-Chernenko Dmitriy <d.chernenko@corp.mail.ru>
+Chernenko Dmitriy <cdn@cpan.org>
 
 =cut
